import { FC, ReactElement } from 'react';
import { ChartShallowDataShape } from '../../common/data';
import { InterpolationTypes } from '../../common/utils';
import { ColorSchemeType } from '../../common/color';
import { Gradient, GradientProps } from '../../common/Gradient';
import { TooltipArea, TooltipAreaProps } from '../../common/Tooltip';
import { Glow } from '../../common';
export interface FunnelArcProps {
    /**
     * Unique identifier for the arc. Set internally by `FunnelChart`.
     */
    id: string;
    /**
     * Data to render the funnel. Set internally by `FunnelChart`.
     */
    data: ChartShallowDataShape[];
    /**
     * Opacity of the funnel arc.
     */
    opacity?: number;
    /**
     * Index of the funnel arc. Set internally by `FunnelChart`.
     */
    index?: number;
    /**
     * The chart funnel style to use.
     */
    variant?: 'default' | 'layered';
    /**
     * xScale for the funnel. Set internally by `FunnelChart`.
     */
    xScale: any;
    /**
     * yScale for the funnel. Set internally by `FunnelChart`.
     */
    yScale: any;
    /**
     * Interpolation for the area. Set internally by `AreaSeries`.
     */
    interpolation: InterpolationTypes;
    /**
     * Color scheme for the chart.
     */
    colorScheme: ColorSchemeType;
    /**
     * Gradient to apply to the area.
     */
    gradient: ReactElement<GradientProps, typeof Gradient> | null;
    /**
     * Glow styling for the arc.
     */
    glow?: Glow;
    /**
     * Tooltip for the chart area.
     */
    tooltip: ReactElement<TooltipAreaProps, typeof TooltipArea>;
}
export declare const FunnelArc: FC<Partial<FunnelArcProps>>;
