import { FC, ReactElement } from 'react';
import { ChartInternalDataShape } from '../../common/data';
import { RadialBar, RadialBarProps } from './RadialBar';
import { ColorSchemeType } from '../../common/color';
import { TooltipAreaProps, TooltipArea } from '../../common/Tooltip';
import { RadialValueMarker, RadialValueMarkerProps } from '../../common';
export type RadialBarSeriesType = 'standard' | 'grouped';
export interface RadialBarSeriesProps {
    /**
     * Parsed data shape. Set internally by `RadialBarChart`.
     */
    data: ChartInternalDataShape[];
    /**
     * Color scheme for the series.
     */
    colorScheme: ColorSchemeType;
    /**
     * The inner radius for the chart center.
     */
    innerRadius: number;
    /**
     * The outer radius for the chart center.
     */
    outerRadius: number;
    /**
     * D3 scale for X Axis. Set internally by `RadialBarChart`.
     */
    xScale: any;
    /**
     * D3 scale for Y Axis. Set internally by `RadialBarChart`.
     */
    yScale: any;
    /**
     * Id set internally by `RadialBarChart`.
     */
    id: string;
    /**
     * Bar that is rendered.
     */
    bar: ReactElement<RadialBarProps, typeof RadialBar>;
    /**
     * Whether to animate the enter/update/exit.
     */
    animated: boolean;
    /**
     * Height of the chart. Set internally by `RadialBarChart`.
     */
    height: number;
    /**
     * Width of the chart. Set internally by `RadialBarChart`.
     */
    width: number;
    /**
     * Tooltip for the chart area.
     */
    tooltip: ReactElement<TooltipAreaProps, typeof TooltipArea>;
    /**
     * Start angle for the first value.
     */
    startAngle?: number;
    /**
     * End angle for the last value.
     */
    endAngle?: number;
    /**
     * The type of the chart.
     */
    type?: RadialBarSeriesType;
    /**
     * Value markers line for the chart.
     */
    valueMarkers: ReactElement<RadialValueMarkerProps, typeof RadialValueMarker>[] | null;
}
export declare const RadialBarSeries: FC<Partial<RadialBarSeriesProps>>;
